==> openjdk-src-19.0.1.u10-2-x86_64.pkg.tar.zst: jdk.localedata/sun/util/resources/cldr/ext/CurrencyNames_tk.java <==
/*
 * Copyright (c) 2012, 2022, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

/*
 * COPYRIGHT AND PERMISSION NOTICE
 *
 * Copyright (c) 1991-2022 Unicode, Inc. All rights reserved.
 * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of the Unicode data files and any associated documentation
 * (the "Data Files") or Unicode software and any associated documentation
 * (the "Software") to deal in the Data Files or Software
 * without restriction, including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, and/or sell copies of
 * the Data Files or Software, and to permit persons to whom the Data Files
 * or Software are furnished to do so, provided that either
 * (a) this copyright and permission notice appear with all copies
 * of the Data Files or Software, or
 * (b) this copyright and permission notice appear in associated
 * Documentation.
 *
 * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
 * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
 * WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT OF THIRD PARTY RIGHTS.
 * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
 * NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
 * DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
 * DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
 * TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
 * PERFORMANCE OF THE DATA FILES OR SOFTWARE.
 *
 * Except as contained in this notice, the name of a copyright holder
 * shall not be used in advertising or otherwise to promote the sale,
 * use or other dealings in these Data Files or Software without prior
 * written authorization of the copyright holder.
 */

package sun.util.resources.cldr.ext;

import sun.util.resources.OpenListResourceBundle;

public class CurrencyNames_tk extends OpenListResourceBundle {
    @Override
    protected final Object[][] getContents() {
        final Object[][] data = new Object[][] {
            { "AED", "AED" },
            { "AFN", "AFN" },
            { "ALL", "ALL" },
            { "AMD", "AMD" },
            { "ANG", "ANG" },
            { "AOA", "AOA" },
            { "ARS", "ARS" },
            { "AWG", "AWG" },
            { "AZN", "AZN" },
            { "BAM", "BAM" },
            { "BBD", "BBD" },
            { "BDT", "BDT" },
            { "BGN", "BGN" },
            { "BHD", "BHD" },
            { "BIF", "BIF" },
            { "BMD", "BMD" },
            { "BND", "BND" },
            { "BOB", "BOB" },
            { "BSD", "BSD" },
            { "BTN", "BTN" },
            { "BWP", "BWP" },
            { "BYN", "BYN" },
            { "BZD", "BZD" },
            { "CDF", "CDF" },
            { "CHF", "CHF" },
            { "CLP", "CLP" },
            { "CNH", "CNH" },
            { "COP", "COP" },
            { "CRC", "CRC" },
            { "CUC", "CUC" },
            { "CUP", "CUP" },
            { "CVE", "CVE" },
            { "CZK", "CZK" },
            { "DJF", "DJF" },
            { "DKK", "DKK" },
            { "DOP", "DOP" },
            { "DZD", "DZD" },
            { "EGP", "EGP" },
            { "ERN", "ERN" },
            { "ETB", "ETB" },
            { "EUR", "EUR" },
            { "FJD", "FJD" },
            { "FKP", "FKP" },
            { "GBP", "GBP" },
            { "GEL", "GEL" },
            { "GHS", "GHS" },
            { "GIP", "GIP" },
            { "GMD", "GMD" },
            { "GNF", "GNF" },
            { "GTQ", "GTQ" },
            { "GYD", "GYD" },
            { "HNL", "HNL" },
            { "HRK", "HRK" },
            { "HTG", "HTG" },
            { "HUF", "HUF" },
            { "IDR", "IDR" },
            { "IQD", "IQD" },
            { "IRR", "IRR" },
            { "ISK", "ISK" },
            { "JMD", "JMD" },
            { "JOD", "JOD" },
            { "KES", "KES" },
            { "KGS", "KGS" },
            { "KHR", "KHR" },
            { "KMF", "KMF" },
            { "KPW", "KPW" },
            { "KWD", "KWD" },
            { "KYD", "KYD" },
            { "KZT", "KZT" },
            { "LAK", "LAK" },
            { "LBP", "LBP" },
            { "LKR", "LKR" },
            { "LRD", "LRD" },
            { "LSL", "LSL" },
            { "LYD", "LYD" },
            { "MAD", "MAD" },
            { "MDL", "MDL" },
            { "MGA", "MGA" },
            { "MKD", "MKD" },
            { "MMK", "MMK" },
            { "MNT", "MNT" },
            { "MOP", "MOP" },
            { "MRO", "MRO" },
            { "MRU", "MRU" },
            { "MUR", "MUR" },
            { "MVR", "MVR" },
            { "MWK", "MWK" },
            { "MYR", "MYR" },
            { "MZN", "MZN" },
            { "NAD", "NAD" },
            { "NGN", "NGN" },
            { "NIO", "NIO" },
            { "NOK", "NOK" },
            { "NPR", "NPR" },
            { "OMR", "OMR" },
            { "PAB", "PAB" },
            { "PEN", "PEN" },
            { "PGK", "PGK" },
            { "PHP", "PHP" },
            { "PKR", "PKR" },
            { "PLN", "PLN" },
            { "PYG", "PYG" },
            { "QAR", "QAR" },
            { "RON", "RON" },
            { "RSD", "RSD" },
            { "RUB", "RUB" },
            { "RWF", "RWF" },
            { "SAR", "SAR" },
            { "SBD", "SBD" },
            { "SCR", "SCR" },
            { "SDG", "SDG" },
            { "SEK", "SEK" },
            { "SGD", "SGD" },
            { "SHP", "SHP" },
            { "SLL", "SLL" },
            { "SOS", "SOS" },
            { "SRD", "SRD" },
            { "SSP", "SSP" },
            { "STN", "STN" },
            { "SYP", "SYP" },
            { "SZL", "SZL" },
            { "THB", "THB" },
            { "TJS", "TJS" },
            { "TMT", "TMT" },
            { "TND", "TND" },
            { "TOP", "TOP" },
            { "TRY", "TRY" },
            { "TTD", "TTD" },
            { "TZS", "TZS" },
            { "UAH", "UAH" },
            { "UGX", "UGX" },
            { "UYU", "UYU" },
            { "UZS", "UZS" },
            { "VEF", "VEF" },
            { "VES", "VES" },
            { "VUV", "VUV" },
            { "WST", "WST" },
            { "YER", "YER" },
            { "ZAR", "ZAR" },
            { "ZMW", "ZMW" },
            { "aed", "BAE dirhemi" },
            { "afn", "Owgan afganisi" },
            { "all", "Alban leki" },
            { "amd", "Ermeni dramy" },
            { "ang", "Niderland antil guldeni" },
            { "aoa", "Angola kwanzasy" },
            { "ars", "Argentin pesosy" },
            { "aud", "Awstrali\u00fda dollary" },
            { "awg", "Aruba florini" },
            { "azn", "Azerba\u00fdjan manady" },
            { "bam", "Konwertirlen\u00fd\u00e4n Bosni\u00fda we Gersegowina markasy" },
            { "bbd", "Barbados dollary" },
            { "bdt", "Banglade\u015f takasy" },
            { "bgn", "Bolgar lewi" },
            { "bhd", "Bahre\u00fdn dinary" },
            { "bif", "Burundi franky" },
            { "bmd", "Bermuda dollary" },
            { "bnd", "Brune\u00fd dollary" },
            { "bob", "Boliwi\u00fda boliwianosy" },
            { "brl", "Brazil realy" },
            { "bsd", "Bagama dollary" },
            { "btn", "Butan ngultrumy" },
            { "bwp", "Botswana pulasy" },
            { "byn", "Belarus rubly" },
            { "byr", "Belorus rubly (2000\u20132016)" },
            { "bzd", "Beliz dollary" },
            { "cad", "Kanada dollary" },
            { "cdf", "Kongo franky" },
            { "chf", "\u015ewe\u00fdsar franky" },
            { "clp", "\u00c7ili pesosy" },
            { "cnh", "Hyta\u00fd \u00fduany (of\u015for)" },
            { "cny", "Hyta\u00fd \u00fduany" },
            { "cop", "Kolumbi\u00fda pesosy" },
            { "crc", "Kosta-Rika kolony" },
            { "cuc", "Konwertirlen\u00fd\u00e4n kuba pesosy" },
            { "cup", "Kuba pesosy" },
            { "cve", "Kabo-Werde eskudosy" },
            { "czk", "\u00c7eh kronasy" },
            { "djf", "Jibuti franky" },
            { "dkk", "Dani\u00fda kronasy" },
            { "dop", "Dominikan pesosy" },
            { "dzd", "Al\u017eir dinary" },
            { "egp", "M\u00fcs\u00fcr funty" },
            { "ern", "Eritre\u00fda nakfasy" },
            { "etb", "Efiopi\u00fda byry" },
            { "eur", "\u00ddewro" },
            { "fjd", "Fiji dollary" },
            { "fkp", "Folklend adalaryny\u0148 funty" },
            { "gbp", "Britan funt sterlingi" },
            { "gel", "Gruzin larisi" },
            { "ghs", "Gano sedisi" },
            { "gip", "Gibraltar funty" },
            { "gmd", "Gambi\u00fda dalasisi" },
            { "gnf", "Gwine\u00fd franky" },
            { "gtq", "Gwatemala ketsaly" },
            { "gyd", "Ga\u00fdana dollary" },
            { "hkd", "Gonkong dollary" },
            { "hnl", "Gonduras lempirasy" },
            { "hrk", "Horwat kunasy" },
            { "htg", "Gaiti gurdy" },
            { "huf", "Wenger forinti" },
            { "idr", "Indonezi\u00fda rupi\u00fdasy" },
            { "ils", "T\u00e4ze Ysra\u00fdyl \u015fekeli" },
            { "inr", "Hindi rupi\u00fdasy" },
            { "iqd", "Yrak dinary" },
            { "irr", "E\u00fdran rialy" },
            { "isk", "Islandi\u00fda kronasy" },
            { "jmd", "\u00ddama\u00fdka dollary" },
            { "jod", "Iordan dinary" },
            { "jpy", "\u00ddapon \u00fdeni" },
            { "kes", "Keni\u00fda \u015fillingi" },
            { "kgs", "Gyrgyz somy" },
            { "khr", "Kamboja ri\u00fdeli" },
            { "kmf", "Komor adalaryny\u0148 franky" },
            { "kpw", "Demirgazyk Kore\u00fd wony" },
            { "krw", "G\u00fcnorta Kore\u00fd wony" },
            { "kwd", "Kuwe\u00fdt dinary" },
            { "kyd", "Ka\u00fdman adalaryny\u0148 dollary" },
            { "kzt", "Gazak te\u0148\u0148esi" },
            { "lak", "Laos kipi" },
            { "lbp", "Liwan funty" },
            { "lkr", "\u015eri-Lanka rupi\u00fdasy" },
            { "lrd", "Liberi\u00fda dollary" },
            { "lsl", "Lesoto lotisi" },
            { "lyd", "Liwi\u00fda dinary" },
            { "mad", "Marokko dirhamy" },
            { "mdl", "Moldaw le\u00fdi" },
            { "mga", "Malagasi\u00fd ariarisi" },
            { "mkd", "Makedon dinary" },
            { "mmk", "M\u00fdanma k\u00fdaty" },
            { "mnt", "Mongol tugrigi" },
            { "mop", "Makao patakasy" },
            { "mro", "Mawritan ugi\u00fdasy (1973\u20132017)" },
            { "mru", "Mawritan ugi\u00fdasy" },
            { "mur", "Mawriki\u00fd rupi\u00fdasy" },
            { "mvr", "Maldiw rufi\u00fdasy" },
            { "mwk", "Malawi kwa\u00e7asy" },
            { "mxn", "Meksikan pesosy" },
            { "myr", "Mala\u00fdzi\u00fda ringgiti" },
            { "mzn", "Mozambik metikaly" },
            { "nad", "Namibi\u00fda dollary" },
            { "ngn", "Nigeri\u00fda na\u00fdrasy" },
            { "nio", "Nikaragua kordobasy" },
            { "nok", "Norwegi\u00fda kronasy" },
            { "npr", "Nepal rupi\u00fdasy" },
            { "nzd", "T\u00e4ze Zelandi\u00fda dollary" },
            { "omr", "Oman rialy" },
            { "pab", "Panama balboasy" },
            { "pen", "Peru soly" },
            { "pgk", "Papua - T\u00e4ze Gwine\u00fda kinasy" },
            { "php", "Filippin pesosy" },
            { "pkr", "P\u00e4kistan rupi\u00fdasy" },
            { "pln", "Pol\u00fdak zlotysy" },
            { "pyg", "Paragwa\u00fd guaranisi" },
            { "qar", "Katar rialy" },
            { "ron", "Rumyn le\u00fdi" },
            { "rsd", "Serb dinary" },
            { "rub", "Rus rubly" },
            { "rwf", "Ruanda franky" },
            { "sar", "Saud rialy" },
            { "sbd", "Solomon adalaryny\u0148 dollary" },
            { "scr", "Se\u00fd\u015fel rupi\u00fdasy" },
            { "sdg", "Sudan funty" },
            { "sek", "\u015ewed kronasy" },
            { "sgd", "Singapur dollary" },
            { "shp", "Keramatly \u00ddelena adasyny\u0148 funty" },
            { "sll", "S\u00fderra-Leone leony" },
            { "sos", "Somali \u015fillingi" },
            { "srd", "Surinam dollary" },
            { "ssp", "G\u00fcnorta Sudan funty" },
            { "std", "San-Tome we Prinsipi dobrasy (1977\u20132017)" },
            { "stn", "San-Tome we Prinsipi dobrasy" },
            { "syp", "Siri\u00fda funty" },
            { "szl", "Swazi lilangeni" },
            { "thb", "Ta\u00fdland baty" },
            { "tjs", "T\u00e4jik somonisi" },
            { "tmt", "T\u00fcrkmen manady" },
            { "tnd", "Tunis dinary" },
            { "top", "Tonga paangasy" },
            { "try", "T\u00fcrk lirasy" },
            { "ttd", "Trininad we Tobago dollary" },
            { "twd", "T\u00e4ze Ta\u00fdwan dollary" },
            { "tzs", "Tanzani\u00fda \u015fillingi" },
            { "uah", "Ukrain griwnasy" },
            { "ugx", "Uganda \u015fillingi" },
            { "usd", "AB\u015e dollary" },
            { "uyu", "Urugwa\u00fd pesosy" },
            { "uzs", "\u00d6zbek somy" },
            { "vef", "Wenesuela boliwary (2008\u20132018)" },
            { "ves", "Wenesuela boliwary" },
            { "vnd", "W\u00fdetnam dongy" },
            { "vuv", "Wanuatu watusy" },
            { "wst", "Samoa talasy" },
            { "xaf", "KFA BEAC franky" },
            { "xcd", "G\u00fcndogar karib dollary" },
            { "xof", "KFA BCEAO franky" },
            { "xpf", "Fransuz \u00fduwa\u015f umman franky" },
            { "xxx", "N\u00e4belli pul birligi" },
            { "yer", "\u00ddemen rialy" },
            { "zar", "G\u00fcnorta Afrika rendi" },
            { "zmw", "Zambi\u00fda kwa\u00e7asy" },
        };
        return data;
    }
}

==> openjdk-src-23.0.2.u7-1.1-x86_64.pkg.tar.zst: jdk.localedata/sun/util/resources/cldr/ext/CurrencyNames_tk.java <==
/*
 * Copyright (c) 2012, 2025, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

/*
 * COPYRIGHT AND PERMISSION NOTICE
 *
 * Copyright (c) 1991-2022 Unicode, Inc. All rights reserved.
 * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of the Unicode data files and any associated documentation
 * (the "Data Files") or Unicode software and any associated documentation
 * (the "Software") to deal in the Data Files or Software
 * without restriction, including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, and/or sell copies of
 * the Data Files or Software, and to permit persons to whom the Data Files
 * or Software are furnished to do so, provided that either
 * (a) this copyright and permission notice appear with all copies
 * of the Data Files or Software, or
 * (b) this copyright and permission notice appear in associated
 * Documentation.
 *
 * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
 * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
 * WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT OF THIRD PARTY RIGHTS.
 * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
 * NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
 * DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
 * DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
 * TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
 * PERFORMANCE OF THE DATA FILES OR SOFTWARE.
 *
 * Except as contained in this notice, the name of a copyright holder
 * shall not be used in advertising or otherwise to promote the sale,
 * use or other dealings in these Data Files or Software without prior
 * written authorization of the copyright holder.
 */

package sun.util.resources.cldr.ext;

import sun.util.resources.OpenListResourceBundle;

public class CurrencyNames_tk extends OpenListResourceBundle {
    @Override
    protected final Object[][] getContents() {
        final Object[][] data = new Object[][] {
            { "EUR", "EUR" },
            { "GBP", "GBP" },
            { "PHP", "PHP" },
            { "aed", "BAE dirhemi" },
            { "afn", "Owgan afganisi" },
            { "all", "Alban leki" },
            { "amd", "Ermeni dramy" },
            { "ang", "Niderland antil guldeni" },
            { "aoa", "Angola kwanzasy" },
            { "ars", "Argentin pesosy" },
            { "aud", "Awstrali\u00fda dollary" },
            { "awg", "Aruba florini" },
            { "azn", "Azerba\u00fdjan manady" },
            { "bam", "Konwertirlen\u00fd\u00e4n Bosni\u00fda we Gersegowina markasy" },
            { "bbd", "Barbados dollary" },
            { "bdt", "Banglade\u015f takasy" },
            { "bgn", "Bolgar lewi" },
            { "bhd", "Bahre\u00fdn dinary" },
            { "bif", "Burundi franky" },
            { "bmd", "Bermuda dollary" },
            { "bnd", "Brune\u00fd dollary" },
            { "bob", "Boliwi\u00fda boliwianosy" },
            { "brl", "Brazil realy" },
            { "bsd", "Bagama dollary" },
            { "btn", "Butan ngultrumy" },
            { "bwp", "Botswana pulasy" },
            { "byn", "Belarus rubly" },
            { "byr", "Belorus rubly (2000\u20132016)" },
            { "bzd", "Beliz dollary" },
            { "cad", "Kanada dollary" },
            { "cdf", "Kongo franky" },
            { "chf", "\u015ewe\u00fdsar franky" },
            { "clp", "\u00c7ili pesosy" },
            { "cnh", "Hyta\u00fd \u00fduany (of\u015for)" },
            { "cny", "Hyta\u00fd \u00fduany" },
            { "cop", "Kolumbi\u00fda pesosy" },
            { "crc", "Kosta-Rika kolony" },
            { "cuc", "Konwertirlen\u00fd\u00e4n kuba pesosy" },
            { "cup", "Kuba pesosy" },
            { "cve", "Kabo-Werde eskudosy" },
            { "czk", "\u00c7eh kronasy" },
            { "djf", "Jibuti franky" },
            { "dkk", "Dani\u00fda kronasy" },
            { "dop", "Dominikan pesosy" },
            { "dzd", "Al\u017eir dinary" },
            { "egp", "M\u00fcs\u00fcr funty" },
            { "ern", "Eritre\u00fda nakfasy" },
            { "etb", "Efiopi\u00fda byry" },
            { "eur", "\u00ddewro" },
            { "fjd", "Fiji dollary" },
            { "fkp", "Folklend adalaryny\u0148 funty" },
            { "gbp", "Britan funt sterlingi" },
            { "gel", "Gruzin larisi" },
            { "ghs", "Gano sedisi" },
            { "gip", "Gibraltar funty" },
            { "gmd", "Gambi\u00fda dalasisi" },
            { "gnf", "Gwine\u00fd franky" },
            { "gtq", "Gwatemala ketsaly" },
            { "gyd", "Ga\u00fdana dollary" },
            { "hkd", "Gonkong dollary" },
            { "hnl", "Gonduras lempirasy" },
            { "hrk", "Horwat kunasy" },
            { "htg", "Gaiti gurdy" },
            { "huf", "Wenger forinti" },
            { "idr", "Indonezi\u00fda rupi\u00fdasy" },
            { "ils", "T\u00e4ze Ysra\u00fdyl \u015fekeli" },
            { "inr", "Hindi rupi\u00fdasy" },
            { "iqd", "Yrak dinary" },
            { "irr", "E\u00fdran rialy" },
            { "isk", "Islandi\u00fda kronasy" },
            { "jmd", "\u00ddama\u00fdka dollary" },
            { "jod", "Iordan dinary" },
            { "jpy", "\u00ddapon \u00fdeni" },
            { "kes", "Keni\u00fda \u015fillingi" },
            { "kgs", "Gyrgyz somy" },
            { "khr", "Kamboja ri\u00fdeli" },
            { "kmf", "Komor adalaryny\u0148 franky" },
            { "kpw", "Demirgazyk Kore\u00fd wony" },
            { "krw", "G\u00fcnorta Kore\u00fd wony" },
            { "kwd", "Kuwe\u00fdt dinary" },
            { "kyd", "Ka\u00fdman adalaryny\u0148 dollary" },
            { "kzt", "Gazak te\u0148\u0148esi" },
            { "lak", "Laos kipi" },
            { "lbp", "Liwan funty" },
            { "lkr", "\u015eri-Lanka rupi\u00fdasy" },
            { "lrd", "Liberi\u00fda dollary" },
            { "lsl", "Lesoto lotisi" },
            { "lyd", "Liwi\u00fda dinary" },
            { "mad", "Marokko dirhamy" },
            { "mdl", "Moldaw le\u00fdi" },
            { "mga", "Malagasi\u00fd ariarisi" },
            { "mkd", "Makedon dinary" },
            { "mmk", "M\u00fdanma k\u00fdaty" },
            { "mnt", "Mongol tugrigi" },
            { "mop", "Makao patakasy" },
            { "mro", "Mawritan ugi\u00fdasy (1973\u20132017)" },
            { "mru", "Mawritan ugi\u00fdasy" },
            { "mur", "Mawriki\u00fd rupi\u00fdasy" },
            { "mvr", "Maldiw rufi\u00fdasy" },
            { "mwk", "Malawi kwa\u00e7asy" },
            { "mxn", "Meksikan pesosy" },
            { "myr", "Mala\u00fdzi\u00fda ringgiti" },
            { "mzn", "Mozambik metikaly" },
            { "nad", "Namibi\u00fda dollary" },
            { "ngn", "Nigeri\u00fda na\u00fdrasy" },
            { "nio", "Nikaragua kordobasy" },
            { "nok", "Norwegi\u00fda kronasy" },
            { "npr", "Nepal rupi\u00fdasy" },
            { "nzd", "T\u00e4ze Zelandi\u00fda dollary" },
            { "omr", "Oman rialy" },
            { "pab", "Panama balboasy" },
            { "pen", "Peru soly" },
            { "pgk", "Papua - T\u00e4ze Gwine\u00fda kinasy" },
            { "php", "Filippin pesosy" },
            { "pkr", "P\u00e4kistan rupi\u00fdasy" },
            { "pln", "Pol\u00fdak zlotysy" },
            { "pyg", "Paragwa\u00fd guaranisi" },
            { "qar", "Katar rialy" },
            { "ron", "Rumyn le\u00fdi" },
            { "rsd", "Serb dinary" },
            { "rub", "Rus rubly" },
            { "rwf", "Ruanda franky" },
            { "sar", "Saud rialy" },
            { "sbd", "Solomon adalaryny\u0148 dollary" },
            { "scr", "Se\u00fd\u015fel rupi\u00fdasy" },
            { "sdg", "Sudan funty" },
            { "sek", "\u015ewed kronasy" },
            { "sgd", "Singapur dollary" },
            { "shp", "Keramatly \u00ddelena adasyny\u0148 funty" },
            { "sle", "S\u00fderra-Leone leony" },
            { "sll", "S\u00fderra-Leone leony (1964\u20142022)" },
            { "sos", "Somali \u015fillingi" },
            { "srd", "Surinam dollary" },
            { "ssp", "G\u00fcnorta Sudan funty" },
            { "std", "San-Tome we Prinsipi dobrasy (1977\u20132017)" },
            { "stn", "San-Tome we Prinsipi dobrasy" },
            { "syp", "Siri\u00fda funty" },
            { "szl", "Swazi lilangeni" },
            { "thb", "Ta\u00fdland baty" },
            { "tjs", "T\u00e4jik somonisi" },
            { "tmt", "T\u00fcrkmen manady" },
            { "tnd", "Tunis dinary" },
            { "top", "Tonga paangasy" },
            { "try", "T\u00fcrk lirasy" },
            { "ttd", "Trininad we Tobago dollary" },
            { "twd", "T\u00e4ze Ta\u00fdwan dollary" },
            { "tzs", "Tanzani\u00fda \u015fillingi" },
            { "uah", "Ukrain griwnasy" },
            { "ugx", "Uganda \u015fillingi" },
            { "usd", "AB\u015e dollary" },
            { "uyu", "Urugwa\u00fd pesosy" },
            { "uzs", "\u00d6zbek somy" },
            { "vef", "Wenesuela boliwary (2008\u20132018)" },
            { "ves", "Wenesuela boliwary" },
            { "vnd", "W\u00fdetnam dongy" },
            { "vuv", "Wanuatu watusy" },
            { "wst", "Samoa talasy" },
            { "xaf", "KFA BEAC franky" },
            { "xcd", "G\u00fcndogar karib dollary" },
            { "xof", "KFA BCEAO franky" },
            { "xpf", "Fransuz \u00fduwa\u015f umman franky" },
            { "xxx", "N\u00e4belli pul birligi" },
            { "yer", "\u00ddemen rialy" },
            { "zar", "G\u00fcnorta Afrika rendi" },
            { "zmw", "Zambi\u00fda kwa\u00e7asy" },
        };
        return data;
    }
}
